class QueryToolLocatorsCss:
    btn_save_file = "#btn-save-file"
    btn_execute_query = "#btn-flash"
    btn_query_dropdown = "#btn-query-dropdown"
    btn_auto_rollback = "#btn-auto-rollback"
    btn_auto_rollback_check_status = "#btn-auto-rollback > i"
    btn_auto_commit = "#btn-auto-commit"
    btn_auto_commit_check_status = "#btn-auto-commit > i"
    btn_cancel_query = "#btn-cancel-query"
    btn_explain = "#btn-explain"
    btn_explain_analyze = "#btn-explain-analyze"
    btn_explain_options_dropdown = "#btn-explain-options-dropdown"
    btn_explain_verbose = "#btn-explain-verbose"
    btn_explain_costs = "#btn-explain-costs"
    btn_explain_buffers = "#btn-explain-buffers"
    btn_explain_timing = "#btn-explain-timing"
    btn_clear_dropdown = "#btn-clear-dropdown"
    btn_clear = "#btn-clear"
    query_editor_panel = "#output-panel"
    query_history_selected = "#query_list .selected"
    query_history_detail = "#query_detail"
    editor_panel = "#output-panel"
    query_messages_panel = ".sql-editor-message"
